/*
 * @Description: 
 * @Date: 2022-11-11 16:39:44
 * @LastEditors: Li Dong
 * @LastEditTime: 2022-11-12 17:47:19
 * @FilePath: \crf\dragForm\vite.config.ts
 */
import { defineConfig } from 'vite'
import vue from '@vitejs/plugin-vue'


import { resolve } from "path"
import { createSvgIconsPlugin } from "vite-plugin-svg-icons"
import Components from 'unplugin-vue-components/vite'
import { AntDesignVueResolver, VantResolver } from 'unplugin-vue-components/resolvers'



// import { getThemeVariables } from 'ant-design-vue/dist/theme'

function generateModifyVars(dark = true) {
  // const modifyVars = getThemeVariables({ dark })

  return {
    // ...modifyVars,
    // hack: `${modifyVars.hack} @import (reference) "${resolve('src/design/config.less')}";`,
    //antd主题颜色
    'primary-color': '#417DE1', // 全局主色
    'link-color': '#1890ff', // 链接色
    'success-color': '#52c41a', // 成功色
    'warning-color': '#faad14', // 警告色
    'error-color': '#f5222d', // 错误色
    'font-size-base': '14px', // 主字号
    'heading-color': 'rgba(0, 0, 0, 0.85)', // 标题色
    'text-color': 'rgba(0, 0, 0, 0.65)', // 主文本色
    'text-color-secondary': 'rgba(0, 0, 0, 0.45)', // 次文本色
    'disabled-color': 'rgba(0, 0, 0, 0.25)', // 失效色
    'border-radius-base': '4px', // 组件/浮层圆角
    'border-color-base': '#d9d9d9', // 边框色
    'box-shadow-base': '0 2px 8px rgba(0, 0, 0, 0.15)', // 浮层阴影
    //自定义的颜色
    'layout-color': '#9867f7'
  }
}


// https://vitejs.dev/config/
export default defineConfig({
  plugins: [
    vue(),
    createSvgIconsPlugin({
      // 指定需要缓存的图标文件夹
      iconDirs: [resolve(process.cwd(), "src/assets/svg")],
      // 指定symbolId格式
      symbolId: "icon-[dir]-[name]",

      /**
       * 自定义插入位置
       * @default: body-last
       */
      inject: "body-last",

      /**
       * custom dom id
       * @default: __svg__icons__dom__
       */
      customDomId: "__svg__icons__dom__",
    }),

    Components({
      resolvers: [AntDesignVueResolver(), VantResolver()],
    }),
  ],
  resolve: {
    alias: {
      "@": resolve(__dirname, ".", "src"),
      "#": resolve(__dirname, ".", "types"),
    },
  },
  css: {
    preprocessorOptions: {
      less: {
        modifyVars: generateModifyVars(),
        javascriptEnabled: true,
      },
    },
  },
  build: {
    outDir: "./lib",
    lib: {
      entry: resolve(__dirname, 'src/components/index.ts'),
      name: "fyclouddrag",
      fileName: "fyclouddrag"
    },
    rollupOptions: {
      external: ['vue'],
      output: {
        globals: {
          vue: "Vue"
        }
      }
    }
  }
})
